@@ -1,7 +1,7 @@
 /* -*- mode: c++ -*- */
 /*
   MyServer
-  Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010 Free Software
+  Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
   Foundation, Inc.
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,10 +21,8 @@
 #ifndef SHA1_CRYPT_H
 # define SHA1_CRYPT_H
 
-extern "C"
-{
-#include <sha1.h>
-}
+# include <sha1.h>
+
 
 # include "myserver.h"
 
