@@ -1,8 +1,8 @@
 /* -*- mode: c++ -*- */
 /*
   MyServer
-  Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008, 2009, 2010 Free
-  Software Foundation, Inc.
+  Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008, 2009, 2010, 2011
+  Free Software Foundation, Inc.
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
@@ -58,20 +58,26 @@ public:
   static int completePath (string &fileName);
 
   static int isDirectory (const char*);
-  static int isDirectory (const string& dir){return isDirectory (dir.c_str ());}
+  static int isDirectory (const string& dir)
+  {return isDirectory (dir.c_str ());}
+
+  static bool notDirectory (const char *path);
+  static bool notDirectory (const string &path)
+  {return notDirectory (path.c_str ());}
 
   static int isLink (const char*);
   static int isLink (const string& dir){return isLink (dir.c_str ());}
 
   static int getShortFileName (char*,char*,int);
 
-  static int fileExists (const char * );
-  static int fileExists (string const &file)
-  {return fileExists (file.c_str ());}
+  static int nodeExists (const char * );
+  static int nodeExists (string const &file)
+  {return nodeExists (file.c_str ());}
 
   static int deleteFile (const char * );
   static int deleteFile (string const &file)
   {return deleteFile (file.c_str ());}
+  static int deleteDir (string const &);
 
   static int renameFile (const char*, const char*);
   static int renameFile (string const &before, string const &after)
@@ -82,6 +88,8 @@ public:
   static int copyFile (string const &src, string const &dest, int overwrite)
   {return copyFile (src.c_str (), dest.c_str (), overwrite);}
 
+  static int copyDir (string const &, string const &, int overwrite);
+
   static void getFileExt (char* ext,const char* filename);
   static void getFileExt (string& ext, string const &filename);
 
@@ -89,8 +97,6 @@ public:
   static void splitPath (const char* path, char* dir, char*filename);
   static void splitPath (string const &path, string& dir, string& filename);
 
-  static int getFilenameLength (const char*, int *);
-  static void getFilename (const char* path, char* filename);
   static void getFilename (string const &path, string& filename);
 
   static int rmdir (const char *path);
