@@ -1,8 +1,8 @@
 /* -*- mode: c++ -*- */
 /*
   MyServer
-  Copyright (C) 2002, 2003, 2004, 2009, 2010 Free Software Foundation,
-  Inc.
+  Copyright (C) 2002, 2003, 2004, 2009, 2010, 2011 Free Software
+  Foundation, Inc.
   Copyright (C) 2004, Guinet Adrien (grainailleur)
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ public:
   MemBuf (MemBuf& srcBuf, int bCopy);
   ~MemBuf ();
 
-  void setExternalBuffer (const void* pAdr, size_t size);
+  void setExternalBuffer (void* pAdr, size_t size);
   int setBuffer (const void* pAdr, size_t size);
   void setLength (size_t newSize);
   void setRealLength (size_t newSize);
