@@ -1,8 +1,8 @@
 /* -*- mode: c++ -*- */
 /*
   MyServer
-  Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008, 2009, 2010 Free
-  Software Foundation, Inc.
+  Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008, 2009, 2010, 2011
+  Free Software Foundation, Inc.
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
@@ -102,7 +102,8 @@ public:
   /*! Generate the RSA key for the SSL context. */
   void generateRsaKey ();
 
-  SSL_CTX* getSSLContext ();
+  gnutls_certificate_credentials_t getSSLContext (){return sslContext.getCredentials ();}
+  gnutls_priority_t getSSLPriorityCache (){return sslContext.getPriorityCache ();}
 
   /*! Get the list of hosts allowed.*/
   list<StringRegex*>* getHostList ()
