@@ -1,7 +1,7 @@
 /* -*- mode: c++ -*- */
 /*
   MyServer
-  Copyright (C) 2007, 2009, 2010 Free Software Foundation, Inc.
+  Copyright (C) 2007, 2009, 2010, 2011 Free Software Foundation, Inc.
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
@@ -29,13 +29,12 @@ public:
   VhostManagerHandler ();
   virtual ~VhostManagerHandler ();
   virtual Vhost* getVHost (const char*, const char*, u_short);
-  virtual Vhost* getVHostByNumber (int n);
-  virtual int addVHost (Vhost*);
+  virtual Vhost* getVHost (u_long n);
   virtual int load (const char *resource){return 0;}
 };
 
 /*!
- * Proxy class to a VhostManagerHandler object.
+  Proxy class to a VhostManagerHandler object.
  */
 class VhostManager
 {
@@ -48,9 +47,9 @@ public:
 
   /*! Get a pointer to a vhost.  */
   Vhost* getVHost (const char*,const char*, u_short);
-  Vhost* getVHostByNumber (int n);
-  void registerBuilder (string &name, MAKE_HANDLER builder);
-  VhostManagerHandler *buildHandler (string &name, ListenThreads *lt,
+  Vhost* getVHost (int n);
+  void registerBuilder (const string &name, MAKE_HANDLER builder);
+  VhostManagerHandler *buildHandler (const string &name, ListenThreads *lt,
                                      LogManager *lm);
 
 protected:
