@@ -1,8 +1,8 @@
 /* -*- mode: c++ -*- */
 /*
   MyServer
-  Copyright (C) 2002, 2003, 2004, 2009, 2010 Free Software Foundation,
-  Inc.
+  Copyright (C) 2002, 2003, 2004, 2009, 2010, 2011 Free Software
+  Foundation, Inc.
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
@@ -25,9 +25,7 @@
 # include <include/filter/gzip/gzip.h>
 
 # ifdef HAVE_ZLIB
-#  include "zlib.h"
-# else
-#  define z_stream (void*)
+#  include <zlib.h>
 # endif
 
 
@@ -36,7 +34,9 @@ class GzipDecompress : public Filter
 public:
   struct GzipData
   {
+# ifdef HAVE_ZLIB
     z_stream stream;
+# endif
     u_long crc;
     u_long data_size;
     u_long initialized;
@@ -46,28 +46,28 @@ public:
   GzipDecompress ();
   ~GzipDecompress ();
 
-  u_long updateCRC (char* buffer,int size);
-  u_long getFooter (char *str,int size);
+  u_long updateCRC (char* buffer, size_t size);
+  u_long getFooter (char *str, size_t size);
   u_long initialize ();
-  u_long decompress (const char* in, u_long sizeIn,
-                     char *out,u_long sizeOut);
+  u_long decompress (const char* in, size_t sizeIn,
+                     char *out, size_t sizeOut);
   u_long free ();
-  u_long flush (char *out,u_long sizeOut);
-  u_long getHeader (char *buffer,u_long buffersize);
+  u_long flush (char *out, size_t sizeOut);
+  u_long getHeader (char *buffer, size_t buffersize);
 
-  static Filter* factory (const char* name);
+  static Filter* factory (const char *name);
 
   static u_long headerSize ();
   static u_long footerSize ();
 
   /*! From Filter*/
-  virtual int getHeader (char* buffer, u_long len, u_long* nbw);
-  virtual int getFooter (char* buffer, u_long len, u_long* nbw);
-  virtual int read (char* buffer, u_long len, u_long*);
-  virtual int write (const char* buffer, u_long len, u_long*);
-  virtual int flush (u_long*);
+  virtual int getHeader (char* buffer, size_t len, size_t* nbw);
+  virtual int getFooter (char* buffer, size_t len, size_t* nbw);
+  virtual int read (char* buffer, size_t len, size_t *);
+  virtual int write (const char *buffer, size_t len, size_t *);
+  virtual int flush (size_t *);
   virtual int modifyData ();
-  virtual const char* getName (char* name, u_long len);
+  virtual const char* getName ();
 private:
   int active;
   GzipData data;
