@@ -1,7 +1,7 @@
 /* -*- mode: c++ -*- */
 /*
   MyServer
-  Copyright (C) 2002, 2003, 2004, 2008, 2009, 2010 Free Software
+  Copyright (C) 2002, 2003, 2004, 2008, 2009, 2010, 2011 Free Software
   Foundation, Inc.
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -37,10 +37,10 @@ public:
                     const char* exec = 0, bool execute = false,
                     bool onlyHeader = false);
 private:
-  int sendData (HttpThreadContext* td, Pipe &stdOutFile, FiltersChain& chain,
-                Process& cgiProc, bool onlyHeader, bool nph);
-  int sendHeader (HttpThreadContext* td, Pipe &stdOutFile, FiltersChain& chain,
-                  Process& cgiProc, bool onlyHeader, bool nph, u_long procStartTime,
-                  bool keepalive, bool useChunks, int *ret);
+  int sendData (HttpThreadContext* td, Pipe &stdOutFile, Process& cgiProc,
+                bool onlyHeader, bool nph);
+  int sendHeader (HttpThreadContext* td, Pipe &stdOutFile, Process& cgiProc,
+                  bool onlyHeader, bool nph, u_long procStartTime,
+                  int *ret);
 };
 #endif
