@@ -1,7 +1,8 @@
 /* -*- mode: c++ -*- */
 /*
   MyServer
-  Copyright (C) 2006, 2008, 2009 Free Software Foundation, Inc.
+  Copyright (C) 2006, 2008, 2009, 2010, 2011 Free Software Foundation,
+  Inc.
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
@@ -19,7 +20,7 @@
 #ifndef FILE_STREAM_H
 # define FILE_STREAM_H
 
-# include "stdafx.h"
+# include "myserver.h"
 
 # include <list>
 # include <sstream>
@@ -37,7 +38,7 @@ public:
   FileStream (FiltersFactory*, u_long, Stream*, FiltersChain*);
   string makeNewFileName (string oldFileName);
   virtual u_long streamSize ();
-  virtual int chown (string &uid, string &gid);
+  virtual int chown2 (string &uid, string &gid);
   int const static defaultFileMask;
 protected:
   virtual int streamCycle ();
