@@ -1,7 +1,7 @@
 /* -*- mode: c++ -*- */
 /*
   MyServer
-  Copyright (C) 2005, 2009 Free Software Foundation, Inc.
+  Copyright (C) 2005, 2009, 2010, 2011 Free Software Foundation, Inc.
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
@@ -19,7 +19,7 @@
 #ifndef DYN_HTTP_MANAGER_H
 # define DYN_HTTP_MANAGER_H
 
-# include "stdafx.h"
+# include "myserver.h"
 # include <include/base/xml/xml_parser.h>
 # include <include/protocol/protocol.h>
 # include <include/connection/connection.h>
@@ -36,7 +36,7 @@ public:
   DynamicHttpManager ();
   virtual ~DynamicHttpManager ();
   virtual int send (HttpThreadContext*, ConnectionPtr s, const char *filenamePath,
-                    const char* cgi, int selfExecuted, int onlyHeader = 0) = 0;
+                    const char* cgi, int selfExecuted, bool onlyHeader = false) = 0;
 
 };
 
