@@ -1,7 +1,7 @@
 /* -*- mode: c++ -*- */
 /*
   MyServer
-  Copyright (C) 2002, 2003, 2004, 2008, 2009, 2010 Free Software
+  Copyright (C) 2002, 2003, 2004, 2008, 2009, 2010, 2011 Free Software
   Foundation, Inc.
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -23,8 +23,6 @@
 # include "myserver.h"
 # include <include/connection/connection.h>
 
-extern "C"
-{
 # ifdef WIN32
 #  include <direct.h>
 #  include <errno.h>
@@ -32,7 +30,7 @@ extern "C"
 #  include <string.h>
 #  include <errno.h>
 # endif
-}
+
 
 # include <string>
 using namespace std;
@@ -51,20 +49,20 @@ class HttpHeaders
 {
 public:
   static int buildHTTPRequestHeaderStruct (const char* input,
-                                           u_long inputSize,
-                                           u_long* nHeaderChars,
+                                           size_t inputSize,
+                                           size_t* headerSize,
                                            HttpRequestHeader *request,
                                            Connection* connection);
 
   static int buildHTTPResponseHeaderStruct (const char *input,
                                             HttpResponseHeader *response,
-                                            u_long* nbtr);
+                                            size_t* nbtr);
 
   static int sendHeader (HttpResponseHeader &response, Stream &stream,
                          MemBuf &memBuf, HttpThreadContext *ctx);
 
-  static int validHTTPRequest (const char*, u_long, u_long*, u_long*);
-  static int validHTTPResponse (const char*, u_long*, u_long*);
+  static int validHTTPRequest (const char *, size_t, size_t *, size_t *);
+  static int validHTTPResponse (const char *, size_t *, size_t *);
 
   static void resetHTTPRequest (HttpRequestHeader *request);
   static void resetHTTPResponse (HttpResponseHeader *response);
@@ -72,8 +70,8 @@ public:
   static void buildDefaultHTTPResponseHeader (HttpResponseHeader*);
   static void buildDefaultHTTPRequestHeader (HttpRequestHeader*);
 
-  static u_long buildHTTPResponseHeader (char*, HttpResponseHeader*);
-  static u_long buildHTTPRequestHeader (char*, HttpRequestHeader*);
+  static size_t buildHTTPResponseHeader (char *, HttpResponseHeader*);
+  static size_t buildHTTPRequestHeader (char *, HttpRequestHeader*);
 
 protected:
   static int readReqAuthLine (HttpRequestHeader *request,
