@@ -1,7 +1,7 @@
 /*
   MyServer
-  Copyright (C) 2005, 2007, 2008, 2009, 2010 Free Software Foundation,
-  Inc.
+  Copyright (C) 2005, 2007, 2008, 2009, 2010, 2011 Free Software
+  Foundation, Inc.
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
@@ -18,9 +18,28 @@
 
 #include "myserver.h"
 #include <include/base/dynamic_lib/dynamiclib.h>
+#include <include/base/exceptions/exceptions.h>
+
+
+class DynError : public AbstractServerException
+{
+public:
+  DynError (const char *err)
+  {
+    this->err = err;
+  }
+
+  virtual const char *what () const throw ()
+  {
+    return err;
+  }
+private:
+  const char *err;
+};
+
 
 /*!
- * Initialize class internal data.
+  Initialize class internal data.
  */
 DynamicLibrary::DynamicLibrary ()
 {
@@ -28,7 +47,7 @@ DynamicLibrary::DynamicLibrary ()
 }
 
 /*!
- * Destroy the object.
+  Destroy the object.
  */
 DynamicLibrary::~DynamicLibrary ()
 {
@@ -36,15 +55,18 @@ DynamicLibrary::~DynamicLibrary ()
 }
 
 /*!
- * Load the specified dynamic library. It returns 0 on success.
- * \param filename Name of the file to load.
- * \param globally Set if the library is loaded globally.
+  Load the specified dynamic library. It returns 0 on success.
+  \param filename Name of the file to load.
+  \param globally Set if the library is loaded globally.
  */
-int DynamicLibrary::loadLibrary (const char* filename, int globally)
+int DynamicLibrary::loadLibrary (const char *filename, int globally)
 {
   fileName.assign (filename);
 #ifdef WIN32
   handle = LoadLibrary (filename);
+  /* FIXME: use a real error message.  */
+  if (handle == NULL)
+    throw DynError ("");
 #endif
 
 #ifdef HAVE_DL
@@ -59,29 +81,32 @@ int DynamicLibrary::loadLibrary (const char* filename, int globally)
 # endif
 
   handle = dlopen (filename, flag);
+  if (handle == NULL)
+    throw DynError (dlerror ());
+
 #endif
   return handle ? 0 : 1;
 }
 
 /*!
- *Get a pointer to the specified function. Returns 0 on errors or
- *the function address.
- *\param fnName Function name to find.
+  Get a pointer to the specified symbol. Returns 0 on errors or
+  the symbol address.
+  \param fnName Symbol to find.
  */
-void* DynamicLibrary::getProc (const char* fnName)
+void *DynamicLibrary::getProc (const char *sym)
 {
   if (!handle)
     return 0;
 #ifdef WIN32
-    return (void*) GetProcAddress ((HMODULE)handle, fnName);
+    return (void *) GetProcAddress ((HMODULE) handle, sym);
 #endif
 #ifdef HAVE_DL
-    return (void*) dlsym (handle, fnName);
+    return (void *) dlsym (handle, sym);
 #endif
 }
 
 /*!
- *Close the library. Returns 0 on success.
+  Close the library. Returns 0 on success.
  */
 int DynamicLibrary::close ()
 {
@@ -89,10 +114,15 @@ int DynamicLibrary::close ()
   if (!handle)
     return 1;
 #ifdef WIN32
-    ret = FreeLibrary ((HMODULE)handle) ? 0 : 1;
+    ret = FreeLibrary ((HMODULE) handle) ? 0 : 1;
+    /* FIXME: use a real error message.  */
+    if (! ret)
+      throw DynError ("");
 #endif
 #ifdef HAVE_DL
     ret = dlclose (handle);
+    if (ret)
+      throw DynError (dlerror ());
 #endif
     handle = 0;
     fileName.assign ("");
@@ -100,7 +130,7 @@ int DynamicLibrary::close ()
 }
 
 /*!
- * Return if the object has a valid handle.
+  Return if the object has a valid handle.
  */
 int DynamicLibrary::validHandle ()
 {
