@@ -1,6 +1,7 @@
 /*
   MyServer
-  Copyright (C) 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+  Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+  Foundation, Inc.
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
@@ -16,13 +17,13 @@
 */
 
 #define HASHMAP_CPP
-#include "stdafx.h"
+#include "myserver.h"
 
 #include <include/base/hash_map/hash_map.h>
 #include <string.h>
 
 /*
- *ELF hash function.
+  ELF hash function.
  */
 #define elfHash(data, len){\
    unsigned int h = 0;\
