@@ -1,26 +1,25 @@
 /*
-MyServer
-Copyright (C) 2006, 2007, 2008, 2009, 2010 Free Software Foundation,
-Inc.
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 3 of the License, or
-(at your option) any later version.
+  MyServer
+  Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+  Foundation, Inc.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 
 #include "myserver.h"
 #include <include/base/sync/event.h>
 
-extern "C" {
 #include <string.h>
 #include <stdlib.h>
 #include <stdarg.h>
@@ -37,7 +36,8 @@ extern "C" {
 # endif
 # include <sys/wait.h>
 #endif
-}
+
+#include <include/base/exceptions/checked.h>
 
 #include <sys/types.h>
 
@@ -46,8 +46,8 @@ extern "C" {
 #endif
 
 /*!
- *Constructor for the event class.
- *\param broadcast If true a signal will be sent to all the waiting threads.
+  Constructor for the event class.
+  \param broadcast If true a signal will be sent to all the waiting threads.
  */
 Event::Event (bool broadcast)
 {
@@ -56,18 +56,18 @@ Event::Event (bool broadcast)
 }
 
 /*!
- *Initialize an event.
- *\param broadcast If true a signal will be sent to all the waiting threads.
- *\return nonzero on errors.
+  Initialize an event.
+  \param broadcast If true a signal will be sent to all the waiting threads.
+  \return nonzero on errors.
  */
 int Event::init (bool broadcast)
 {
   int ret = 0;
   if (initialized)
-  {
-    destroy ();
-    initialized = false;
-  }
+    {
+      destroy ();
+      initialized = false;
+    }
   this->broadcast = broadcast;
 #ifdef HAVE_PTHREAD
   ret = pthread_mutex_init (&mutex,(pthread_mutexattr_t*) NULL);
@@ -82,9 +82,9 @@ int Event::init (bool broadcast)
 }
 
 /*!
- *Wait for the event.
- *\param id The calling thread id.
- *\param timeout Timeout value in milliseconds.
+  Wait for the event.
+  \param id The calling thread id.
+  \param timeout Timeout value in milliseconds.
  */
 int Event::wait (u_long id, u_long timeout)
 {
@@ -96,7 +96,7 @@ int Event::wait (u_long id, u_long timeout)
   {
     struct timespec ts;
     struct timeval tp;
-    gettimeofday (&tp, NULL);
+    checked::gettimeofday (&tp, NULL);
     ts.tv_sec = tp.tv_sec + tp.tv_usec / 1000000 + timeout / 1000;
     ts.tv_nsec = (tp.tv_usec * 1000 + timeout * 1000000) % 1000000000;
 
@@ -129,11 +129,11 @@ int Event::wait (u_long id, u_long timeout)
 }
 
 /*!
- *Signal the event.
- *The behaviour of this message is influenced by the broadcast flag, if this
- *is a broadcast event then the event will be signaled to all the waiting
- *threads otherwise only one thread will be signaled.
- *\param id The calling thread id.
+  Signal the event.
+  The behaviour of this message is influenced by the broadcast flag, if this
+  is a broadcast event then the event will be signaled to all the waiting
+  threads otherwise only one thread will be signaled.
+  \param id The calling thread id.
  */
 int Event::signal (u_long id)
 {
@@ -165,7 +165,7 @@ int Event::signal (u_long id)
 
 
 /*!
- *Clean all the used resources.
+  Clean all the used resources.
  */
 int Event::destroy ()
 {
@@ -189,7 +189,7 @@ int Event::destroy ()
 }
 
 /*!
- *Destroy the object.
+  Destroy the object.
  */
 Event::~Event ()
 {
