@@ -1,6 +1,6 @@
 /*
   MyServer
-  Copyright (C) 2009 Free Software Foundation, Inc.
+  Copyright (C) 2009, 2010, 2011 Free Software Foundation, Inc.
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
@@ -15,7 +15,7 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "stdafx.h"
+#include "myserver.h"
 
 #include <include/conf/main/main_configuration.h>
 
