@@ -1,7 +1,7 @@
 /*
   MyServer
-  Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Free
-  Software Foundation, Inc.
+  Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010,
+  2011 Free Software Foundation, Inc.
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
@@ -16,7 +16,7 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "stdafx.h"
+#include "myserver.h"
 
 
 #include <include/conf/security/security_domain.h>
@@ -43,9 +43,9 @@ SecurityDomain::~SecurityDomain ()
 }
 
 /*!
- *Get the stored value for [name].
+  Get the stored value for [name].
  */
-string *SecurityDomain::getValue (string &name)
+const string *SecurityDomain::getValue (string &name)
 {
   return NULL;
 }
