@@ -1,6 +1,7 @@
 /*
   MyServer
-  Copyright (C) 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+  Copyright (C) 2007, 2008, 2009, 2010, 2011 Free Software Foundation,
+  Inc.
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
@@ -169,8 +170,8 @@ vector<Vhost*>* XmlVhostHandler::getVHostList ()
  */
 void XmlVhostHandler::changeLocationsOwner ()
 {
-  if (Server::getInstance ()->getUid () ||
-     Server::getInstance ()->getGid ())
+  if (Server::getInstance ()->getUid ()
+      || Server::getInstance ()->getGid ())
     {
       string uid (Server::getInstance ()->getUid ());
       string gid (Server::getInstance ()->getGid ());
@@ -212,80 +213,84 @@ int XmlVhostHandler::getHostsNumber ()
   Load a log XML node.
  */
 void
-XmlVhostHandler::loadXMLlogData (string name, Vhost* vh, xmlNode* lcur)
+XmlVhostHandler::loadXMLlogData (string name, Vhost *vh, xmlNode *lcur)
 {
   xmlAttr *attr;
   string opt;
   attr = lcur->properties;
   while (attr)
     {
-      opt.append ((char*)attr->name);
+      opt.append ((char *) attr->name);
       opt.append ("=");
-      opt.append ((char*)attr->children->content);
+      opt.append ((char *) attr->children->content);
       if (attr->next)
         {
           opt.append (",");
         }
       attr = attr->next;
     }
+
   string location;
   list<string> filters;
   u_long cycle;
   xmlNode* stream = lcur->children;
-  for (; stream; stream = stream->next, location.assign (""), cycle = 0, filters.clear ())
+  for (; stream; stream = stream->next)
     {
-      if (stream->type == XML_ELEMENT_NODE &&
-          !xmlStrcmp (stream->name, (xmlChar const*) "STREAM"))
-        {
-          xmlAttr* streamAttr = stream->properties;
-          while (streamAttr)
-            {
-              if (!strcmp ((char*)streamAttr->name, "location"))
-                {
-                  location.assign ((char*)streamAttr->children->content);
-                }
-              else if (!strcmp ((char*)streamAttr->name, "cycle"))
-                {
-                  cycle = atoi ((char*)streamAttr->children->content);
-                }
-              streamAttr = streamAttr->next;
-            }
-          xmlNode* filterList = stream->children;
-          for (; filterList; filterList = filterList->next)
-            {
-              if (filterList->type == XML_ELEMENT_NODE &&
-                  !xmlStrcmp (filterList->name, (xmlChar const*) "FILTER"))
-                {
-                  if (filterList->children && filterList->children->content)
-                    {
-                      string filter ((char*)filterList->children->content);
-                      filters.push_back (filter);
-                    }
-                }
-            }
-          int err = 1;
-          string str ("XmlVhostHandler::loadXMLlogData : Unrecognized log type");
+      location.assign ("");
+      cycle = 0;
+      filters.clear ();
 
-          if (!name.compare ("ACCESSLOG"))
-            {
-              err = vh->openAccessLog (location, filters, cycle);
-              vh->setAccessLogOpt (opt.c_str ());
-              if (err)
-                Server::getInstance ()->log (MYSERVER_LOG_MSG_ERROR,
-                                                   _("Error opening %s"), location.c_str ());
-            }
-          else if (!name.compare ("WARNINGLOG"))
-            {
-              err = vh->openWarningLog (location, filters, cycle);
-              vh->setWarningLogOpt (opt.c_str ());
-              if (err)
-                Server::getInstance ()->log (MYSERVER_LOG_MSG_ERROR,
-                                                   _("Error opening %s"), location.c_str ());
-            }
-          else
-            Server::getInstance ()->log (MYSERVER_LOG_MSG_ERROR,
-                                               _(" Unrecognized log type"));
+      if (stream->type != XML_ELEMENT_NODE)
+        continue;
+
+      if (xmlStrcmp (stream->name, (xmlChar const *) "STREAM"))
+        Server::getInstance ()->log (MYSERVER_LOG_MSG_ERROR,
+                                     _("Unexpected element in virtual host streams"));
+
+      xmlAttr* streamAttr = stream->properties;
+      while (streamAttr)
+        {
+          if (!strcmp ((char *) streamAttr->name, "location"))
+            location.assign ((char *) streamAttr->children->content);
+          else if (!strcmp ((char *) streamAttr->name, "cycle"))
+            cycle = atoi ((char *) streamAttr->children->content);
+
+          streamAttr = streamAttr->next;
         }
+
+      xmlNode* filterList = stream->children;
+      for (; filterList; filterList = filterList->next)
+        {
+          if (filterList->type == XML_ELEMENT_NODE &&
+              !xmlStrcmp (filterList->name, (xmlChar const *) "FILTER"))
+            {
+              if (filterList->children && filterList->children->content)
+                {
+                  string filter ((char *) filterList->children->content);
+                  filters.push_back (filter);
+                }
+            }
+        }
+
+      if (! name.compare ("ACCESSLOG"))
+        {
+          int err = vh->openAccessLog (location, filters, cycle);
+          vh->setAccessLogOpt (opt.c_str ());
+          if (err)
+            Server::getInstance ()->log (MYSERVER_LOG_MSG_ERROR,
+                                         _("Error opening %s"), location.c_str ());
+        }
+      else if (! name.compare ("WARNINGLOG"))
+        {
+          int err = vh->openWarningLog (location, filters, cycle);
+          vh->setWarningLogOpt (opt.c_str ());
+          if (err)
+            Server::getInstance ()->log (MYSERVER_LOG_MSG_ERROR,
+                                         _("Error opening %s"), location.c_str ());
+        }
+      else
+        Server::getInstance ()->log (MYSERVER_LOG_MSG_ERROR,
+                                     _(" Unrecognized log type"));
     }
 }
 
@@ -308,7 +313,7 @@ int XmlVhostHandler::load (const char *filename)
   doc = parser.getDoc ();
   node = doc->children->children;
 
-  for (;node;node = node->next )
+  for (; node; node = node->next )
     {
       xmlNodePtr lcur;
       Vhost *vh;
@@ -316,15 +321,6 @@ int XmlVhostHandler::load (const char *filename)
         continue;
       lcur = node->children;
       vh = new Vhost (logManager);
-      if (vh == 0)
-        {
-          parser.close ();
-          clean ();
-          Server::getInstance ()->log (MYSERVER_LOG_MSG_ERROR,
-                                             _("internal error"), filename);
-          return -1;
-        }
-
       SslContext* sslContext = vh->getVhostSSLContext ();
 
       while (lcur)
@@ -344,11 +340,11 @@ int XmlVhostHandler::load (const char *filename)
                         useRegex = 1;
                 }
 
-              vh->addHost ((const char*)lcur->children->content, useRegex);
+              vh->addHost ((const char *)lcur->children->content, useRegex);
             }
           else if (!xmlStrcmp (lcur->name, (const xmlChar *) "NAME"))
             {
-              vh->setName ((char*)lcur->children->content);
+              vh->setName ((char *) lcur->children->content);
             }
           else if (!xmlStrcmp (lcur->name, (const xmlChar *) "LOCATION"))
             {
@@ -356,7 +352,7 @@ int XmlVhostHandler::load (const char *filename)
 
               for (xmlAttr *attrs = lcur->properties; attrs; attrs = attrs->next)
                 if (!xmlStrcmp (attrs->name, (const xmlChar *) "path"))
-                  loc = ((const char*) attrs->children->content);
+                  loc = ((const char *) attrs->children->content);
 
               MimeRecord *record = XmlMimeHandler::readRecord (lcur);
               MimeRecord *prev = vh->addLocationMime (loc, record);
@@ -373,21 +369,21 @@ int XmlVhostHandler::load (const char *filename)
             }
           else if (!xmlStrcmp (lcur->name, (const xmlChar *) "SSL_PRIVATEKEY"))
             {
-              string pk ((char*)lcur->children->content);
+              string pk ((char *) lcur->children->content);
               sslContext->setPrivateKeyFile (pk);
             }
           else if (!xmlStrcmp (lcur->name, (const xmlChar *) "SSL_CERTIFICATE"))
             {
-              string certificate ((char*)lcur->children->content);
+              string certificate ((char *) lcur->children->content);
               sslContext->setCertificateFile (certificate);
             }
           else if (!xmlStrcmp (lcur->name, (const xmlChar *) "CONNECTIONS_PRIORITY"))
             {
-              vh->setDefaultPriority (atoi ((const char*)lcur->children->content));
+              vh->setDefaultPriority (atoi ((const char *)lcur->children->content));
             }
           else if (!xmlStrcmp (lcur->name, (const xmlChar *) "SSL_PASSWORD"))
             {
-              string pw ((char*)lcur->children->content);
+              string pw ((char *) lcur->children->content);
               sslContext->setPassword (pw);
             }
           else if (!xmlStrcmp (lcur->name, (const xmlChar *) "IP"))
@@ -405,40 +401,41 @@ int XmlVhostHandler::load (const char *filename)
                   attrs = attrs->next;
                 }
 
-              vh->addIP ((char*)lcur->children->content, useRegex);
+              vh->addIP ((char *) lcur->children->content, useRegex);
             }
           else if (!xmlStrcmp (lcur->name, (const xmlChar *) "PORT"))
             {
-              int val = atoi ((char*)lcur->children->content);
+              int val = atoi ((char *) lcur->children->content);
               if (val > (1 << 16) || val <= 0)
                 Server::getInstance ()->log (MYSERVER_LOG_MSG_ERROR,
-                      _("Specified invalid port %s"), lcur->children->content);
+                      _("An invalid port was specified: %s"),
+                                             lcur->children->content);
               vh->setPort ((u_short)val);
             }
           else if (!xmlStrcmp (lcur->name, (const xmlChar *) "PROTOCOL"))
             {
-              char* lastChar = (char*)lcur->children->content;
+              char* lastChar = (char *) lcur->children->content;
               while (*lastChar != '\0')
                 {
                   *lastChar = tolower (*lastChar);
                   lastChar++;
                 }
-              vh->setProtocolName ((char*)lcur->children->content);
+              vh->setProtocolName ((char *) lcur->children->content);
             }
           else if (!xmlStrcmp (lcur->name, (const xmlChar *) "DOCROOT"))
             {
-              char* lastChar = (char*)lcur->children->content;
+              char* lastChar = (char *) lcur->children->content;
               while (*(lastChar+1) != '\0')
                 lastChar++;
 
               if (*lastChar == '\\' || *lastChar == '/')
                 *lastChar = '\0';
 
-              vh->setDocumentRoot ((const char*)lcur->children->content);
+              vh->setDocumentRoot ((const char *)lcur->children->content);
             }
           else if (!xmlStrcmp (lcur->name, (const xmlChar *) "SYSROOT"))
             {
-              char* lastChar = (char*)lcur->children->content;
+              char* lastChar = (char *) lcur->children->content;
 
               while (*(lastChar+1) != '\0')
                 lastChar++;
@@ -446,7 +443,7 @@ int XmlVhostHandler::load (const char *filename)
               if (*lastChar == '\\' || *lastChar == '/')
                 *lastChar = '\0';
 
-              vh->setSystemRoot ((const char*)lcur->children->content);
+              vh->setSystemRoot ((const char *)lcur->children->content);
             }
           else if (!xmlStrcmp (lcur->name, (const xmlChar *) "ACCESSLOG"))
             {
@@ -463,10 +460,10 @@ int XmlVhostHandler::load (const char *filename)
                 {
                   if (!xmlStrcmp (attrs->name, (const xmlChar *) "name")
                       && attrs->children && attrs->children->content)
-                    hnd.assign((const char*) attrs->children->content);
+                    hnd.assign((const char *) attrs->children->content);
                 }
 
-              const char *filename = (const char*) lcur->children->content;
+              const char *filename = (const char *) lcur->children->content;
               MimeManagerHandler *handler =
                 Server::getInstance ()->getMimeManager ()->buildHandler (hnd);
 
@@ -487,7 +484,7 @@ int XmlVhostHandler::load (const char *filename)
             }
           else if (!xmlStrcmp (lcur->name, (const xmlChar *) "THROTTLING_RATE"))
             {
-              u_long rate = (u_long)atoi ((char*)lcur->children->content);
+              u_long rate = (u_long)atoi ((char *) lcur->children->content);
               vh->setThrottlingRate (rate);
             }
 
