@@ -1,6 +1,7 @@
 /*
   MyServer
-  Copyright (C) 2006, 2008, 2009, 2010 Free Software Foundation, Inc.
+  Copyright (C) 2006, 2008, 2009, 2010, 2011 Free Software Foundation,
+  Inc.
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
@@ -26,7 +27,7 @@ ConsoleStreamCreator::create (FiltersFactory* ff, string location,
   if (out && !out->openConsole (location))
     {
       size_t nbw;
-      FiltersChain* fc = ff->chain (filters, out, &nbw);
+      FiltersChain* fc = ff->makeChain (filters, out, &nbw);
       if (fc)
         {
           return new ConsoleStream (ff, cycle, out, fc);
