@@ -1,7 +1,7 @@
 /*
   MyServer
-  Copyright (C) 2005, 2007, 2008, 2009, 2010 Free Software Foundation,
-  Inc.
+  Copyright (C) 2005, 2007, 2008, 2009, 2010, 2011 Free Software
+  Foundation, Inc.
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
@@ -26,7 +26,7 @@
 
 
 /*!
- *Default constructor.
+  Default constructor.
  */
 DynamicHttpManager::DynamicHttpManager ()
 {
@@ -34,7 +34,7 @@ DynamicHttpManager::DynamicHttpManager ()
 }
 
 /*!
- *Destroy the object.
+  Destroy the object.
  */
 DynamicHttpManager::~DynamicHttpManager ()
 {
