@@ -1,19 +1,19 @@
 /*
- MyServer
- Copyright (C) 2008, 2009, 2010 Free Software Foundation, Inc.
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 3 of the License, or
- (at your option) any later version.
+  MyServer
+  Copyright (C) 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
 
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
- You should have received a copy of the GNU General Public License
- along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
 
 #include "myserver.h"
 
@@ -25,20 +25,19 @@
 #include <cppunit/ui/text/TestRunner.h>
 #include <cppunit/extensions/HelperMacros.h>
 
-#include "../include/base/socket/ssl_socket.h"
-#include "../include/base/file/file.h"
-#include "../include/base/file/files_utility.h"
-#include "../include/base/thread/thread.h"
-#include "../include/base/utility.h"
+#include <include/base/socket/socket.h>
+#include <include/base/socket/ssl_socket.h>
+#include <include/base/file/file.h>
+#include <include/base/file/files_utility.h>
+#include <include/base/thread/thread.h>
+#include <include/base/utility.h>
 
-extern "C"
-{
 #include <string.h>
 #ifndef WIN32
 # include <errno.h>
 # include <arpa/inet.h>
 #endif
-}
+
 
 #include <string>
 #include <iostream>
@@ -113,14 +112,14 @@ public:
   void setUp ()
   {
     initializeSSL ();
-    u_long nbw;
+    size_t nbw;
     File f;
 
-    f.openFile (TESTSERVERKEY,  File::WRITE | File::FILE_CREATE_ALWAYS);
+    f.openFile (TESTSERVERKEY,  File::WRITE | File::FILE_OPEN_ALWAYS);
     f.writeToFile (serverKey, strlen (serverKey), &nbw);
     f.close ();
 
-    f.openFile (TESTSERVERPEM,  File::WRITE | File::FILE_CREATE_ALWAYS);
+    f.openFile (TESTSERVERPEM,  File::WRITE | File::FILE_OPEN_ALWAYS);
     f.writeToFile (serverPem, strlen (serverPem), &nbw);
     f.close ();
   }
@@ -133,9 +132,12 @@ public:
 
   void testRecv ()
   {
+    gnutls_priority_t priority_cache;
+    gnutls_dh_params_t dh_params;
+    gnutls_certificate_credentials_t cred;
+
     Socket *obj = new Socket;
     SslSocket *sslObj = NULL;
-    SSL_CTX *ctx = NULL;;
     ThreadID tid;
 
     int optvalReuseAddr = 1;
@@ -144,7 +146,7 @@ public:
     int status;
 
     ((sockaddr_in*) (&sockIn))->sin_family = AF_INET;
-    ((sockaddr_in*) (&sockIn))->sin_addr.s_addr = inet_addr ("127.0.0.1");
+    ((sockaddr_in*) (&sockIn))->sin_addr.s_addr = inet_addr (LOCALHOST_ADDRESS);
     ((sockaddr_in*) (&sockIn))->sin_port = htons (port);
 
     socklen_t sockInLen = sizeof (sockaddr_in);
@@ -155,19 +157,21 @@ public:
                                       (const char*) &optvalReuseAddr,
                                       sizeof (optvalReuseAddr)) != -1);
 
-    ctx = SSL_CTX_new (SSLv23_server_method ());
 
-    if (SSL_CTX_use_certificate_file (ctx, TESTSERVERPEM, SSL_FILETYPE_PEM) != 1)
-    {
-      SSL_CTX_free (ctx);
-      CPPUNIT_ASSERT (false);
-    }
+    gnutls_certificate_allocate_credentials (&cred);
+    gnutls_priority_init (&priority_cache, "NORMAL", NULL);
+
+    gnutls_dh_params_init (&dh_params);
+    gnutls_dh_params_generate2 (dh_params, 1024);
+    gnutls_certificate_set_dh_params (cred, dh_params);
+
+    gnutls_certificate_set_x509_trust_file (cred, TESTSERVERPEM,
+                                            SSL_FILETYPE_PEM);
+
+    gnutls_certificate_set_x509_key_file (cred, TESTSERVERPEM,
+                                          TESTSERVERKEY,
+                                          GNUTLS_X509_FMT_PEM);
 
-    if (SSL_CTX_use_PrivateKey_file (ctx, TESTSERVERKEY, SSL_FILETYPE_PEM) != 1)
-    {
-      SSL_CTX_free (ctx);
-      CPPUNIT_ASSERT (false);
-    }
 
     /* If the port is used by another program, try a few others.  */
     do
@@ -190,16 +194,15 @@ public:
     Socket s = obj->accept (&sockIn, &sockInLen);
 
     sslObj = new SslSocket (&s);
-    sslObj->setSSLContext (ctx);
+    sslObj->setSSLContext (cred, priority_cache);
 
     int ret = sslObj->sslAccept ();
     if (ret < 0)
-    {
-      delete obj;
-      delete sslObj;
-      SSL_CTX_free (ctx);
-      CPPUNIT_ASSERT (false);
-    }
+      {
+        delete obj;
+        delete sslObj;
+        CPPUNIT_ASSERT (false);
+      }
 
     char buf[32] = {0};
 
@@ -213,12 +216,13 @@ public:
 
     CPPUNIT_ASSERT (obj->close () != -1);
 
-    SSL_CTX_free (ctx);
-
     Thread::join (tid);
     if (!arg.success)
       throw arg.reason;
 
+    gnutls_certificate_free_credentials (cred);
+    gnutls_priority_deinit (priority_cache);
+
     delete obj;
     delete sslObj;
   }
@@ -234,7 +238,7 @@ static DEFINE_THREAD (testSslRecvClient, pParam)
   MYSERVER_SOCKADDRIN sockIn = { 0 };
 
   ((sockaddr_in*) (&sockIn))->sin_family = AF_INET;
-  ((sockaddr_in*) (&sockIn))->sin_addr.s_addr = inet_addr ("127.0.0.1");
+  ((sockaddr_in*) (&sockIn))->sin_addr.s_addr = inet_addr (LOCALHOST_ADDRESS);
   ((sockaddr_in*) (&sockIn))->sin_port = htons (arg->port);
 
   int sockInLen = sizeof (struct sockaddr_in);
